@@ -1,6 +1,7 @@
-/* Copyright (c) 1996, 1999-2004, 2007 MySQL AB
-   Use is subject to license terms
-   This file is public domain and comes with NO WARRANTY of any kind */
+/* Copyright Abandoned 1996,1999 TCX DataKonsult AB & Monty Program KB
+   & Detron HB, 1996, 1999-2004, 2007 MySQL AB.
+   This file is public domain and comes with NO WARRANTY of any kind
+*/
 
 /* Version numbers for protocol & mysqld */
 
@@ -10,12 +11,12 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"10.0.8-MariaDB"
+#define MYSQL_SERVER_VERSION		"10.0.11-MariaDB"
 #define MYSQL_BASE_VERSION		"mysqld-10.0"
 #define MARIADB_BASE_VERSION		"mariadb-10.0"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		100008
+#define MYSQL_VERSION_ID		100011
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/tmp/mysql.sock"
